"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.createValidatorAsync = createValidatorAsync;
exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _formatErrorMessage = _interopRequireDefault(require("./formatErrorMessage"));

/**
 * Create a data asynchronous validator
 * @param data
 */
function createValidatorAsync(data, name) {
  function check(errorMessage) {
    return function (checkResult) {
      if (checkResult === false) {
        return {
          hasError: true,
          errorMessage: errorMessage
        };
      } else if (typeof checkResult === 'object' && (checkResult.hasError || checkResult.array)) {
        return checkResult;
      }

      return null;
    };
  }

  return function (value, rules) {
    var promises = rules.map(function (rule) {
      var onValid = rule.onValid,
          errorMessage = rule.errorMessage,
          params = rule.params;
      return Promise.resolve(onValid(value, data, name)).then(check((0, _formatErrorMessage["default"])(errorMessage, (0, _extends2["default"])({}, params, {
        name: Array.isArray(name) ? name.join('.') : name
      }))));
    });
    return Promise.all(promises).then(function (results) {
      return results.find(function (item) {
        return item && (item === null || item === void 0 ? void 0 : item.hasError);
      });
    });
  };
}

var _default = createValidatorAsync;
exports["default"] = _default;